@@ -45,9 +45,6 @@ def check_args(arguments):
     if not os.path.isdir(arguments.fastq):
         raise NotADirectoryError(f"Cannot find dir: {arguments.fastq}")
 
-    if not os.path.isdir(arguments.summary):
-        raise NotADirectoryError(f"Cannot find dir: {arguments.summary}")
-
     if not os.path.isdir(arguments.ref):
         raise NotADirectoryError(f"Cannot find dir: {arguments.ref}")
 
@@ -285,6 +282,7 @@ def parse_input_files(mode, ad_base, ref_path):
         #print(AD_REF, DB_REF)
         AD_GENES = read_genes_from_fasta(f"{AD_REF}.fasta")
         DB_GENES = read_genes_from_fasta(f"{DB_REF}.fasta")
+
     else:
         raise ValueError("Please provide valid mode: yeast, human, virus, hedgy or LAgag")
 
